@@ -1,5 +1,5 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el,v 18.0 2003/04/29 21:18:07 raman Exp $
+;;; $Id: emacspeak-table-ui.el,v 23.505 2005/11/25 16:30:50 raman Exp $
 ;;; $Author: raman $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2003/04/29 21:18:07 $ |
-;;;  $Revision: 18.0 $ | 
+;;; $Date: 2005/11/25 16:30:50 $ |
+;;;  $Revision: 23.505 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2003, T. V. Raman 
+;;;Copyright (C) 1995 -- 2004, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -96,6 +96,9 @@
   (define-key emacspeak-table-keymap "a"
     'emacspeak-table-select-automatic-speaking-method)
   (define-key emacspeak-table-keymap "s" 'emacspeak-table-search)
+  (define-key emacspeak-table-keymap "C"
+    'emacspeak-table-search-column)
+  (define-key emacspeak-table-keymap "R" 'emacspeak-table-search-row)
   (define-key emacspeak-table-keymap "f" 'emacspeak-table-speak-row-filtered)
   (define-key emacspeak-table-keymap "g" 'emacspeak-table-speak-column-filtered)
   (define-key emacspeak-table-keymap "h"
@@ -104,7 +107,7 @@
   (define-key emacspeak-table-keymap "T" 'emacspeak-table-goto-top)
   (define-key emacspeak-table-keymap "B" 'emacspeak-table-goto-bottom)
   (define-key emacspeak-table-keymap "L" 'emacspeak-table-goto-left)
-  (define-key emacspeak-table-keymap "R" 'emacspeak-table-goto-right)
+  (define-key emacspeak-table-keymap "E" 'emacspeak-table-goto-right)
   )
 
 (defun emacspeak-table-mode ()
@@ -356,8 +359,8 @@ Optional prefix arg prompts for a new filter."
                                         (emacspeak-table-ui-generate-key))
                                        "("))))
     (emacspeak-table-ui-filter-set
-     (emacspeak-table-ui-generate-key
-      )emacspeak-table-speak-row-filter))
+     (emacspeak-table-ui-generate-key)
+     emacspeak-table-speak-row-filter))
   (let ((voice-lock-mode t))
     (dtk-speak
      (mapconcat
@@ -443,7 +446,7 @@ Optional prefix arg prompts for a new filter."
 (defsubst emacspeak-table-prepare-table-buffer (table buffer
                                                       &optional filename)
   "Prepare tabular data."
-  (declare (special positions ))
+  (declare (special emacspeak-table positions ))
   (save-excursion
     (set-buffer buffer)
     (let ((i 0)
@@ -546,8 +549,7 @@ The processed  data and presented using emacspeak table navigation. "
 ;;;###autoload
 (defun emacspeak-table-view-csv-buffer (&optional buffer-name)
   "Process a csv (comma separated values) data. 
-The processed  data and presented using emacspeak table
-navigation. "
+The processed  data and presented using emacspeak table navigation. "
   (interactive)
   (or buffer-name
       (setq buffer-name (current-buffer)))
@@ -597,7 +599,8 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "r")
-  (declare (special positions))
+  (declare (special emacspeak-table
+                    positions))
   (let ((workspace (get-buffer-create " table workspace  "))
         (buffer (get-buffer-create
                  (format  "*table-%s*"
@@ -807,11 +810,12 @@ browsing table elements"
 ;;}}}
 ;;{{{ searching and finding:
 
-(defun emacspeak-table-search ()
+(defun emacspeak-table-search (&optional what)
   "Search the table for matching elements.  Interactively prompts for
 row or column to search and pattern to look for.    If there is a match, makes
-the matching cell current."
-  (interactive )
+the matching cell current. When called from a program, `what' can
+  be either `row' or `column'."
+  (interactive "P")
   (declare (special emacspeak-table))
   (unless (boundp 'emacspeak-table)
     (error "Cannot find table associated with this buffer"))
@@ -819,11 +823,12 @@ the matching cell current."
   (let* ((row (emacspeak-table-current-row emacspeak-table))
          (column (emacspeak-table-current-column emacspeak-table))
          (found nil)
-         (slice 
-          (case (read-char)
-            (?r 'row)
-            (?c 'column)
-            (otherwise (error "Can only search in either row or column"))))
+         (slice
+          (or what 
+	      (case (read-char)
+		(?r 'row)
+		(?c 'column)
+		(otherwise (error "Can only search in either row or column")))))
          (pattern (read-string
                    (format "Search in current  %s for: " slice ))))
     (cond
@@ -845,6 +850,15 @@ the matching cell current."
       (emacspeak-auditory-icon 'search-hit))
      (t (emacspeak-auditory-icon 'search-miss)))
     (funcall emacspeak-table-speak-element)))
+(defun emacspeak-table-search-row ()
+  "Search in current table row."
+  (interactive)
+  (emacspeak-table-search 'row))
+
+(defun emacspeak-table-search-column ()
+  "Search in current table column."
+  (interactive)
+  (emacspeak-table-search 'column))
 
 (defun emacspeak-table-search-headers ()
   "Search the table row or column headers.  Interactively prompts for
@@ -1062,11 +1076,13 @@ markup to use."
 (defun emacspeak-table-sort-on-current-column ()
   "Sort table on current column. "
   (interactive )
-  (declare (special major-mode
-                    emacspeak-table))
+  (declare (special major-mode emacspeak-table
+                    emacspeak-table-speak-row-filter))
   (unless (eq major-mode  'emacspeak-table-mode )
     (error "This command should be used in emacspeak table mode."))
-  (let* ((column  (emacspeak-table-current-column emacspeak-table))
+  (let* ((column  (emacspeak-table-current-column
+		   emacspeak-table))
+         (row-filter emacspeak-table-speak-row-filter)
          (elements
           (loop for e across (emacspeak-table-elements emacspeak-table)
                 collect e))
@@ -1079,13 +1095,14 @@ markup to use."
            (function
             (lambda (x y)
               (cond
+               ((and (numberp (read (aref x column)))
+                     (numberp (read (aref y column))))
+                (< (read (aref x column))
+                   (read (aref y column))))
                ((and (stringp  (aref x column))
                      (stringp (aref y column)))
                 (string-lessp (aref x column)
                               (aref y column)))
-               ((and (numberp (aref x column))
-                     (numberp (aref y column)))
-                (< (aref x column) (aref y column)))
                (t (string-lessp
                    (format "%s" (aref x column))
                    (format "%s" (aref y column)))))))))
@@ -1096,6 +1113,9 @@ markup to use."
     (emacspeak-table-prepare-table-buffer
      (emacspeak-table-make-table  sorted-table)
      buffer)
+    (save-excursion
+      (set-buffer buffer)
+      (setq emacspeak-table-speak-row-filter row-filter))
     (emacspeak-speak-mode-line)))
 
 ;;}}}
@@ -1170,7 +1190,7 @@ future  use."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
